diff --git a/IPython/html/static/widgets/js/widget.js b/IPython/html/static/widgets/js/widget.js
index 4345a41..2c3cec4 100644
--- a/IPython/html/static/widgets/js/widget.js
+++ b/IPython/html/static/widgets/js/widget.js
@@ -269,8 +269,8 @@ define(["widgets/js/manager",
}
},
- on_atomic_change: function(keys, callback, context) {
- // on__atomic_change(["key1", "key2"], foo, context) differs from
+ on_some_change: function(keys, callback, context) {
+ // on_some_change(["key1", "key2"], foo, context) differs from
// on("change:key1 change:key2", foo, context).
// If the widget attributes key1 and key2 are both modified,
// the second form will result in foo being called twice